@@ -6,11 +6,13 @@ from cachebot.logger import CacheLogDecorator
 
 @CacheLogDecorator
 class DummyCache(dummy.DummyCache):
+    
+    def append(self, **kwargs):
+        pass
+    
+    def prepend(self, **kwargs):
+        pass
 
-    def __init__(self, *args, **kwargs):
-        super(DummyCache, self).__init__(*args, **kwargs)
-        self._logger = CacheLogger()
-        
     def replace(self, **kwargs):
         pass
         
